<?php
/**
 *
 *
 * @link              https://www.wingfield.gr.jp/
 * @since             0.1
 * @package           WF_List_Bookmarks
 *
 * @wordpress-plugin
 * Plugin Name:       WINGFIELD List Bookmarks
 * Plugin URI:        https://www.wingfield.gr.jp/downloads/
 * Description:       This plugin enables link manager and shows bookmarks list using easy shortcode.
 * Version:           0.1
 * Author:            WINGFIELD since1981
 * Author URI:        https://www.wingfield.gr.jp/
 * License:           GPL-2.0+
 * License URI:       https://www.wingfield.gr.jp/about/policy/
 * Text Domain:       wf-list-bookmarks
 * Domain Path:       /languages
 */

// リンク機能の有効化
add_filter( 'pre_option_link_manager_enabled', '__return_true' );

if (!function_exists('wf_show_bookmarks')) {
	function wf_show_bookmarks( $atts ) {//$init_array
			
		// パラメーター		
		$atts = shortcode_atts(array(
			'categorize' => true,			//カテゴリー別に表示するかどうか
			'category_before' => '<li>',	//カテゴリー名の前に連結する文字列  id="%id" class="%class"
			'category_after' => '</li>',	//カテゴリー名の後に連結する文字列
			'echo' => true,					//HTML出力するかどうか
			'editlink' => true,				//ログイン時に編集リンクを表示
			'link_target' => false,			//リンクの target 属性
			'orderby' => 'slug',			//ソート順 (slug, count, name, term_id のいずれか）
			'parent' => '',					//親スラッグ
			'show_images' => false,			//画像の表示
			'show_rss' => true,				//RSS リンクの表示
			'title_before' => '<h2>',		//見出し名の前に連結する文字列
			'title_after' => '</h2>',		//見出し名の後に連結する文字列
		),$atts);
		
		$r = '';
	
		//スラッグ名からIDを取得
		$term    = get_term_by('slug', $atts['parent'], 'link_category');
		$term_id = $term->term_id;
		
		$terms = get_terms(array( 'taxonomy'=>'link_category', 'parent'=>$term_id));
		
		//link_category をスラッグ名でソート
		//※get_germs() では link_category での絞り込みやソートが効かない、slug、、none、
		usort($terms, function ($a, $b) {
			switch ($atts['orderby']) {
				case 'count':
					return strcmp($a->count, $b->count);
					break;
				case 'name':
					return strcmp($a->name, $b->name);
					break;
				case 'term_id':
					return strcmp($a->id, $b->id);
					break;
				default:
					return strcmp($a->slug, $b->slug);
			}
			
		}); 
		if (!empty($terms)) {
			
			//カテゴリー別に表示しない
			if ($atts['categorize']) {
				foreach($terms as $term) {
					//リンク カテゴリーIDで絞り込み
					$bookmarks = get_bookmarks( array('category' => (int)$term->term_id));
					if (!empty($bookmarks)) {
						//カテゴリー別に表示
						if ($atts['categorize']) {
							//リンク カテゴリー 名前
							$r .= $atts['title_before'] . esc_html($term->name) . $atts['title_after'];
							
							//リンク カテゴリー 説明
							if ($term->description != ''){					
								$r .= '<p>' . $term->description . '</p>';
							}
							
							$r .=  '<ul>';
						}
						
						foreach ( $bookmarks as $bookmark ) {
							
							
							//リンク先が自サイトの場合同一ウィンドウでジャンプ
							if ($atts['link_target']){
								if ($bookmark->link_target == ''){
									$link_target = '_self';
								}
								else{
									$link_target = $bookmark->link_target;
								}
								
							}
							else{
								if(strpos($bookmark->link_url,get_bloginfo( 'url' )) !== false){
									$link_target = '_self';
								}
								else{
									$link_target = '_blank';
								}
							}
							
							
							$r .= $atts['category_before'];
														
							$r .= '<a href="'.esc_url($bookmark->link_url).'" target="'. $link_target .'">';
							
							//ブックマーク 画像
							if ($atts['show_images'] && $bookmark->link_image != ''){				
								$r .= '<img src="' . $bookmark->link_image . '" style="max-height:50px;">';
							}
							else{
								$r .= esc_html($bookmark->link_name);
							}
							$r .= '</a>';
							
							//ブックマーク RSS
							if ($atts['show_rss'] && $bookmark->link_rss != ''){
								$r .= '&nbsp;<a href="' . $bookmark->link_rss . '" target="' . $link_target . '"><img src="' . plugins_url( 'images/rss.png', __FILE__ ). '" style="vertical-align:baseline;"></a>';	  
							}							
							
							//ログイン時編集リンク
							if (is_user_logged_in() && $atts['editlink'] == true){ 
								$r .= '（<a href="' . admin_url() . 'link.php?action=edit&link_id=' . $bookmark->link_id . '">' . __( 'Edit' , 'default' ) . '</a>）';
							}
							
							//ブックマーク 説明
							if ($bookmark->link_description != ''){
								$r .= '</br>';
								
								//HTML構文除外
								if ($atts['echo'] == true){
									$r .= $bookmark->link_description;
								}
								else{
									$r .= strip_tags($bookmark->link_description);
								}
								
							}
							$r .= $atts['category_after'];
						}
						
						//カテゴリー別に表示
						if ($atts['categorize']) {
							$r .=  '</ul>';
						}
					}
				}
			}
			else{
				$r = '"categorize" parameter is not implemented.' ;
			}
		}
		
		return $r;
	}
}
add_shortcode('wf-bookmarks', 'wf_show_bookmarks');

?>